@@ -16,3 +16,10 @@ exclude_patterns = []
 html_theme = "pydata_sphinx_theme"
 
 jupyterlite_dir = "."
+
+html_theme_options = {
+   "logo": {
+      "image_light": "xeus-python.svg",
+      "image_dark": "xeus-python.svg",
+   }
+}
